Index: Source/bindings/scripts/v8_types.py |
diff --git a/Source/bindings/scripts/v8_types.py b/Source/bindings/scripts/v8_types.py |
index 87ecead4857831ae8be9bbd712e848bd1dede054..27ef87e8000f25b536e3bbec4c32260b336da538 100644 |
--- a/Source/bindings/scripts/v8_types.py |
+++ b/Source/bindings/scripts/v8_types.py |
@@ -928,11 +928,11 @@ def cpp_type_has_null_value(idl_type): |
# - String types (String/AtomicString) represent null as a null string, |
# i.e. one for which String::isNull() returns true. |
# - Enum types, as they are implemented as Strings. |
# - Wrapper types (raw pointer or RefPtr/PassRefPtr) represent null as |
# a null pointer. |
# - Union types, as thier container classes can represent null value. |
# - 'Object' type. We use ScriptValue for object type. |
- return (idl_type.is_string_type or idl_type.is_wrapper_type or |
+ return (idl_type.is_string_type or idl_type.is_interface_type or |
idl_type.is_enum or idl_type.is_union_type |
or idl_type.base_type == 'object') |
@@ -928,11 +928,11 @@ def cpp_type_has_null_value(idl_type): |
# i.e. one for which String::isNull() returns true. |
# - Enum types, as they are implemented as Strings. |
- # - Wrapper types (raw pointer or RefPtr/PassRefPtr) represent null as |
+ # - Interface types (raw pointer or RefPtr/PassRefPtr) represent null as |
# a null pointer. |
# - Union types, as thier container classes can represent null value. |